@@ -244,6 +244,14 @@ class Version(object):
             while version.count('.') < 2:
                 version += '.0'
 
+        # Strip leading zeros in components
+        # Version is of the form nn, nn.pp or nn.pp.qq
+        version = '.'.join(
+            # If the part was '0', we end up with an empty string.
+            part.lstrip('0') or '0'
+            for part in version.split('.')
+        )
+
         if match.end() == len(version_string):
             return Version(version, partial=partial)
 
@@ -673,6 +681,19 @@ class Clause(object):
     def __eq__(self, other):
         raise NotImplementedError()
 
+    def prettyprint(self, indent='\t'):
+        """Pretty-print the clause.
+        """
+        return '\n'.join(self._pretty()).replace('\t', indent)
+
+    def _pretty(self):
+        """Actual pretty-printing logic.
+
+        Yields:
+            A list of string. Indentation is performed with \t.
+        """
+        yield repr(self)
+
     def __ne__(self, other):
         return not self == other
 
@@ -733,6 +754,15 @@ class AnyOf(Clause):
     def __repr__(self):
         return 'AnyOf(%s)' % ', '.join(sorted(repr(c) for c in self.clauses))
 
+    def _pretty(self):
+        yield 'AnyOF('
+        for clause in self.clauses:
+            lines = list(clause._pretty())
+            for line in lines[:-1]:
+                yield '\t' + line
+            yield '\t' + lines[-1] + ','
+        yield ')'
+
 
 class AllOf(Clause):
     __slots__ = ['clauses']
@@ -789,6 +819,15 @@ class AllOf(Clause):
     def __repr__(self):
         return 'AllOf(%s)' % ', '.join(sorted(repr(c) for c in self.clauses))
 
+    def _pretty(self):
+        yield 'AllOF('
+        for clause in self.clauses:
+            lines = list(clause._pretty())
+            for line in lines[:-1]:
+                yield '\t' + line
+            yield '\t' + lines[-1] + ','
+        yield ')'
+
 
 class Matcher(Clause):
     __slots__ = []
@@ -1084,7 +1123,7 @@ class SimpleSpec(BaseSpec):
                 elif minor is None:
                     return Range(Range.OP_GTE, target) & Range(Range.OP_LT, target.next_major())
                 elif patch is None:
-                    return Range(Range.OP_GTE, target) & Range(Range.OP_LT, target.next_patch())
+                    return Range(Range.OP_GTE, target) & Range(Range.OP_LT, target.next_minor())
                 elif build == '':
                     return Range(Range.OP_EQ, target, build_policy=Range.BUILD_STRICT)
                 else:
@@ -1242,7 +1281,7 @@ class NpmSpec(BaseSpec):
                                 prerelease_policy=Range.PRERELEASE_ALWAYS,
                             ))
                         elif clause.operator in (Range.OP_LT, Range.OP_LTE):
-                            prerelease_clauses.append(cls.range(
+                            prerelease_clauses.append(Range(
                                 operator=Range.OP_GTE,
                                 target=Version(
                                     major=clause.target.major,
@@ -1250,6 +1289,7 @@ class NpmSpec(BaseSpec):
                                     patch=0,
                                     prerelease=(),
                                 ),
+                                prerelease_policy=Range.PRERELEASE_ALWAYS,
                             ))
                         prerelease_clauses.append(clause)
                         non_prerel_clauses.append(cls.range(
